@@ -3,6 +3,7 @@ from fastapi.middleware.cors import CORSMiddleware
 
 from apiautomata.routes import echo, home, missing, proxy
 from apiautomata.routes.exchange import instrument_exchange
+from apiautomata.routes.transform import exchange_transform
 
 app = FastAPI()
 
@@ -11,6 +12,7 @@ app.include_router(echo.router)
 app.include_router(proxy.router)
 app.include_router(missing.router)
 app.include_router(instrument_exchange.router)
+app.include_router(exchange_transform.router)
 
 origins = ['*']
 
